@@ -1,7 +1,7 @@
 #!/usr/bin/env perl
 use strict;
 use warnings;
-use 5.008003;
+use 5.008000;
 
 use Term::ReadLine::Simple;
 
@@ -9,10 +9,12 @@ use FindBin qw( $RealBin );
 use lib $RealBin;
 use Data_Test_Arguments;
 
-my $a_ref = Data_Test_Arguments::valid_args();
-my $args = $a_ref->[shift]{args};
-
 my $tiny  = Term::ReadLine::Simple->new();
-my $line = $tiny->readline( @$args );
+my $a_ref = Data_Test_Arguments::valid_args();
 
-print "<$line>\n";
+for my $ref ( @$a_ref  ) {
+    my $args = $ref->{args};
+
+    my $line = $tiny->readline( @$args );
+    print "<$line>\n";
+}
